@@ -15,7 +15,13 @@ import aws_cdk.aws_s3
 import aws_cdk.aws_ssm
 import aws_cdk.core
 import aws_cdk.cx_api
+import aws_cdk.region_info
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ec2", "1.34.0", __name__[0:-6], "aws-ec2@1.34.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
